@@ -5,9 +5,11 @@ from mutwo import parameters
 DEFAULT_PLAYING_INDICATORS_COLLECTION_CLASS = (
     parameters.playing_indicators.PlayingIndicatorCollection
 )
-"""Default value for `playing_indicators` in :class:`mutwo.events.music.NoteLike`"""
+"""Default value for :attr:`~mutwo.events.music.NoteLike.playing_indicators`
+in :class:`~mutwo.events.music.NoteLike`"""
 
 DEFAULT_NOTATION_INDICATORS_COLLECTION_CLASS = (
     parameters.notation_indicators.NotationIndicatorCollection
 )
-"""Default value for `notation_indicators` in :class:`mutwo.events.music.NoteLike`"""
+"""Default value for :attr:`~mutwo.events.music.NoteLike.notation_indicators`
+in :class:`~mutwo.events.music.NoteLike`"""
